@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: mupdate-client.c,v 1.59 2008/10/08 15:47:08 murch Exp $
+ * $Id: mupdate-client.c,v 1.61 2009/04/23 17:10:07 murch Exp $
  */
 
 #include <config.h>
@@ -77,6 +77,7 @@
 #include "mupdate.h"
 #include "prot.h"
 #include "protocol.h"
+#include "util.h"
 #include "xmalloc.h"
 #include "xstrlcpy.h"
 #include "xstrlcat.h"
@@ -89,9 +90,11 @@ static struct protocol_t mupdate_protocol =
   { NULL, NULL, "* OK", NULL,
     { { "* AUTH ", CAPA_AUTH },
       { "* STARTTLS", CAPA_STARTTLS },
+      { "* COMPRESS \"DEFLATE\"", CAPA_COMPRESS },
       { NULL, 0 } } },
   { "S01 STARTTLS", "S01 OK", "S01 NO", 0 },
   { "A01 AUTHENTICATE", INT_MAX, 1, "A01 OK", "A01 NO", "", "*", NULL, 0 },
+  { "Z01 COMPRESS \"DEFLATE\"", NULL, "Z01 OK" },
   { "N01 NOOP", NULL, "N01 OK" },
   { "Q01 LOGOUT", NULL, "Q01 " }
 };
@@ -500,11 +503,11 @@ int mupdate_scarf(mupdate_handle *handle,
 	    break;
 	}
 	
-	if (islower((unsigned char) handle->cmd.s[0])) {
+	if (Uislower(handle->cmd.s[0])) {
 	    handle->cmd.s[0] = toupper((unsigned char) handle->cmd.s[0]);
 	}
 	for (p = &(handle->cmd.s[1]); *p; p++) {
-	    if (islower((unsigned char) *p))
+	    if (Uislower(*p))
 		*p = toupper((unsigned char) *p);
 	}
 	
