@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: libconfig.c,v 1.21 2008/09/23 17:34:38 murch Exp $
+ * $Id: libconfig.c,v 1.24 2009/08/20 15:26:15 murch Exp $
  */
 
 #include <config.h>
@@ -60,6 +60,7 @@
 #include "xmalloc.h"
 #include "xstrlcat.h"
 #include "xstrlcpy.h"
+#include "util.h"
 
 #define CONFIGHASHSIZE 30 /* relatively small,
 			   * because it is for overflow only */
@@ -148,6 +149,8 @@ const char *config_getoverflowstring(const char *key, const char *def)
     char buf[256];
     char *ret = NULL;
 
+    if (!config_filename) return 0;
+
     /* First lookup <ident>_key, to see if we have a service-specific
      * override */
 
@@ -169,6 +172,8 @@ const char *config_getoverflowstring(const char *key, const char *def)
 void config_foreachoverflowstring(void (*func)(const char *, const char *, void *),
 				  void *rock)
 {
+    if (!config_filename) return;
+
     hash_enumerate(&confighash, (void (*)(char *, void *, void *)) func, rock);
 }
 
@@ -196,6 +201,15 @@ const char *config_metapartitiondir(const char *partition)
     return config_getoverflowstring(buf, NULL);
 }
 
+static void config_ispartition(const char *key,
+			       const char *val __attribute__((unused)),
+			       void *rock)
+{
+    int *found = (int *) rock;
+
+    if (!strncmp("partition-", key, 10)) *found = 1;
+}
+
 void config_read(const char *alt_config)
 {
     enum imapopt opt = IMAPOPT_ZERO;
@@ -263,18 +277,31 @@ void config_read(const char *alt_config)
 
     /* Look up default partition */
     config_defpartition = config_getstring(IMAPOPT_DEFAULTPARTITION);
-    for (p = (char *)config_defpartition; *p; p++) {
-	if (!isalnum((unsigned char) *p))
+    for (p = (char *)config_defpartition; p && *p; p++) {
+	if (!Uisalnum(*p))
 	  fatal("defaultpartition option contains non-alphanumeric character",
 		EC_CONFIG);
-	if (isupper((unsigned char) *p)) *p = tolower((unsigned char) *p);
+	if (Uisupper(*p)) *p = tolower((unsigned char) *p);
     }
-    if ((config_need_data & CONFIG_NEED_PARTITION_DATA) &&
-	(!config_defpartition || !config_partitiondir(config_defpartition))) {
-	snprintf(buf, sizeof(buf),
-		"partition-%s option not specified in configuration file",
-		config_defpartition);
-	fatal(buf, EC_CONFIG);
+
+    if (config_need_data & CONFIG_NEED_PARTITION_DATA) {
+	int found = 0;
+
+	if (config_defpartition) {
+	    /* see if defaultpartition is specified properly */
+	    if (config_partitiondir(config_defpartition)) found = 1;
+	}
+	else {
+	    /* see if we have ANY partition-<name> options */
+	    config_foreachoverflowstring(config_ispartition, &found);
+	}
+
+	if (!found) {
+	    snprintf(buf, sizeof(buf),
+		     "partition-%s option not specified in configuration file",
+		     config_defpartition ? config_defpartition : "<name>");
+	    fatal(buf, EC_CONFIG);
+	}
     }
 
     /* look up mailbox hashing */
@@ -370,15 +397,15 @@ void config_read_file(const char *filename)
 	service_specific = 0;
 
 	/* remove leading whitespace */
-	for (p = buf; *p && isspace((int) *p); p++);
+	for (p = buf; *p && Uisspace(*p); p++);
 
 	/* skip comments */
 	if (!*p || *p == '#') continue;
 
 	fullkey = key = p;
 	if (*p == '@') p++;  /* allow @ as the first char (for directives) */
-	while (*p && (isalnum((int) *p) || *p == '-' || *p == '_')) {
-	    if (isupper((unsigned char) *p)) *p = tolower((unsigned char) *p);
+	while (*p && (Uisalnum(*p) || *p == '-' || *p == '_')) {
+	    if (Uisupper(*p)) *p = tolower((unsigned char) *p);
 	    p++;
 	}
 	if (*p != ':') {
@@ -390,10 +417,10 @@ void config_read_file(const char *filename)
 	*p++ = '\0';
 	
 	/* remove leading whitespace */
-	while (*p && isspace((int) *p)) p++;
+	while (*p && Uisspace(*p)) p++;
 	
 	/* remove trailing whitespace */
-	for (q = p + strlen(p) - 1; q > p && isspace((int) *q); q--) {
+	for (q = p + strlen(p) - 1; q > p && Uisspace(*q); q--) {
 	    *q = '\0';
 	}
 	
@@ -553,7 +580,7 @@ void config_read_file(const char *filename)
 
 		while (*p) {
 		    /* find the end of the first value */
-		    for (; *q && !isspace((int) *q); q++);
+		    for (; *q && !Uisspace(*q); q++);
 		    if (*q) *q++ = '\0';
 
 		    /* see if its a legal value */
@@ -574,7 +601,7 @@ void config_read_file(const char *filename)
 			imapopts[opt].val.x |= e->val;
 
 		    /* find the start of the next value */
-		    for (p = q; *p && isspace((int) *p); p++);
+		    for (p = q; *p && Uisspace(*p); p++);
 		    q = p;
 		}
 
