@@ -38,7 +38,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: isieve.c,v 1.34 2008/04/22 13:11:18 murch Exp $
+ * $Id: isieve.c,v 1.36 2009/02/16 18:18:10 murch Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,6 +55,7 @@
 #include <netinet/in.h>
 #include <netdb.h>
 #include <string.h>
+#include <unistd.h>
 
 #include <sasl/sasl.h>
 #include <sasl/saslutil.h>
@@ -208,10 +209,14 @@ int init_sasl(isieve_t *obj,
   addrsize=sizeof(struct sockaddr_storage);
   if (getsockname(obj->sock,(struct sockaddr *)&saddr_l,&addrsize)!=0)
       return -1;
-
+#if 0
+  /* XXX  The following line causes problems with KERBEROS_V4 decoding.
+   * We're not sure why its an issue, but this code isn't used in any of 
+   * our other client code (imtest.c, backend.c), so we're removing it.
+   */
   /* set the port manually since getsockname is stupid and doesn't */
   ((struct sockaddr_in *)&saddr_l)->sin_port = htons(obj->port);
-
+#endif
   if (iptostring((struct sockaddr *)&saddr_r, addrsize, remoteip, 60))
       return -1;
 
@@ -299,6 +304,33 @@ char * read_capability(isieve_t *obj)
   return cap;
 }
 
+int detect_mitm(isieve_t *obj, char *mechlist)
+{
+    char *new_mechlist;
+    int ch, r = 0;
+
+    /* wait and probe for possible automatic capability response */
+    usleep(250000);
+    prot_NONBLOCK(obj->pin);
+    if ((ch = prot_getc(obj->pin)) != EOF) {
+	/* automatic capability response */
+	prot_ungetc(ch, obj->pin);
+    } else {
+	/* manually ask for capabilities */
+	prot_printf(obj->pout, "CAPABILITY\r\n");
+	prot_flush(obj->pout);
+    }
+    prot_BLOCK(obj->pin);
+
+    if ((new_mechlist = read_capability(obj))) {
+	/* if the server still advertises SASL mechs, compare lists */
+	r = strcmp(new_mechlist, mechlist);
+	free(new_mechlist);
+    }
+
+    return r;
+}
+
 static int getauthline(isieve_t *obj, char **line, unsigned int *linelen,
 		       char **errstrp)
 {
@@ -631,10 +663,12 @@ int do_referral(isieve_t *obj, char *refer_to)
     if(ret) return STAT_NO;
 
     if (ssf) {
-	/* SASL security layer negotiated --
-	   server will automatically send capabilites */
-	free(mechlist);
-	mechlist = read_capability(obj_new);
+        /* SASL security layer negotiated --
+	   check if SASL mech list changed */
+        if (detect_mitm(obj_new, mechlist)) {
+	    free(mechlist);
+	    return STAT_NO;
+	}
     }
     free(mechlist);
 
