@@ -40,7 +40,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: sievec.c,v 1.8 2008/03/24 20:08:46 murch Exp $
+ * $Id: sievec.c,v 1.9 2009/03/25 23:58:04 brong Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -91,14 +91,14 @@ int main(int argc, char **argv)
 	}
 
     if (usage_error || (argc - optind) < 2) {
-	printf("Syntax: %s [-C <altconfig>] <filename> <outputfile>\n",
+	fprintf(stderr, "Syntax: %s [-C <altconfig>] <filename> <outputfile>\n",
 	       argv[0]);
 	exit(1);
     }
 
     instream = fopen(argv[optind++],"r");
     if(instream == NULL) {
-	printf("Unable to open %s for reading\n", argv[1]);
+	fprintf(stderr, "Unable to open %s for reading\n", argv[1]);
 	exit(1);
     }
     
@@ -107,9 +107,9 @@ int main(int argc, char **argv)
 
     if(is_script_parsable(instream, &err, &s) == TIMSIEVE_FAIL) {
 	if(err) {
-	    printf("Unable to parse script: %s\n", err);
+	    fprintf(stderr, "Unable to parse script: %s\n", err);
 	} else {
-	    printf("Unable to parse script.\n");
+	    fprintf(stderr, "Unable to parse script.\n");
 	}
 	 
 	exit(1);
@@ -117,20 +117,20 @@ int main(int argc, char **argv)
     
     /* Now, generate the bytecode */
     if(sieve_generate_bytecode(&bc, s) == -1) {
-	printf("bytecode generate failed\n");
+	fprintf(stderr, "bytecode generate failed\n");
 	exit(1);
     }
 
     /* Now, open the new file */
     fd = open(argv[optind], O_CREAT | O_TRUNC | O_WRONLY, 0644);
     if(fd < 0) {
-	printf("couldn't open bytecode output file\n");
+	fprintf(stderr, "couldn't open bytecode output file\n");
 	exit(1);
     }  
 
     /* Now, emit the bytecode */
     if(sieve_emit_bytecode(fd, bc) == -1) {
-	printf("bytecode emit failed\n");
+	fprintf(stderr, "bytecode emit failed\n");
 	exit(1);
     }
 
@@ -180,7 +180,7 @@ static int mysieve_error(int lineno, const char *msg,
 
 void fatal(const char *s, int code)
 {  
-    printf("Fatal error: %s (%d)\r\n", s, code);
+    fprintf(stderr, "Fatal error: %s (%d)\r\n", s, code);
                            
     exit(1);
 }
